{{ names|join(", ") }} Report

{% extends "layout.html" %} {% from '_card_helpers.html' import render_plot_card %} {% block title -%} {%- endblock %} {% block topscript -%}
{%- endblock %} {% block header -%} {{ names|join(", ") }} Report {%- endblock %} {% block content -%}
{{ render_plot_card('Basic Information', basics) }} {{ render_plot_card('Stoichiometric Consistency', consistency) }} {# {{ render_plot_card('Syntax Information', basics) }} #} Syntax Information
{{ render_plot_card('Biomass Production', biomass) }} {# {{ render_plot_card('Annotation Information', basics) }} #} Annotation Information
{%- endblock %} {% block bottomscript %} {{ super() }}
{%- endblock %}